@@ -5,13 +5,11 @@ Wrappery dla komend wykonywanych na Calibre
 """
 from __future__ import print_function
 
-import os.path
-import subprocess
-import re
+import os, subprocess, re, time, sys
 from lxml import objectify
-import sys
 from collections import namedtuple
 from tempfile import NamedTemporaryFile
+from shutil import copyfile
 
 from mekk.calibre.config import standard_config, CONFIG_LOCATION
 CONFIG = standard_config()
@@ -20,6 +18,8 @@ CONFIG = standard_config()
 # Internal helpers
 ############################################################
 
+DAY_SECONDS = 24 * 60 * 60  # 24 hours
+MAX_CACHE_AGE = 1 * DAY_SECONDS
 
 def calibre_query_files(search=None, use_cache=False):
     """
@@ -37,39 +37,52 @@ def calibre_query_files(search=None, use_cache=False):
     #options.extend(["--sort-by", "id"])
     options.extend(["--sort-by", "timestamp"])
 
-    # In case we do not search, it makes sense to reuse cached copy (or save it)
-    catalog_file = None
-    persist_catalog = False
-    if search is None and use_cache:
-        catalog_file = os.path.join(CONFIG.cache_dir, "catalog.xml")
-        persist_catalog = True
-        if os.path.exists(catalog_file):
-            print("Reusing cached catalog ({0})".format(catalog_file))
-            return objectify.parse(open(catalog_file))\
-                            .getroot()\
-                            .iterchildren(reversed=True)
-    else:
-        catalog_file = NamedTemporaryFile(suffix=".xml", delete=False)
-        catalog_file.close()
-        catalog_file = catalog_file.name
-        persist_catalog = False
+    def return_from_catalog(catalog_file):
+        return objectify.parse(open(catalog_file))\
+                        .getroot()\
+                        .iterchildren(reversed=True)
+
+    def generate_catalog(catalog_file, options):
+        try:
+            subprocess.check_call(
+                [CONFIG.calibredb, "catalog", catalog_file] + options)
+        except OSError as err:
+            if err.errno == 2:
+                raise Exception("""calibredb (configured as %s) not found.
+    Install Calibre, or edit %s to set proper path to it.""" % (
+                        CONFIG.calibredb, CONFIG_LOCATION))
+            else:
+                raise
+
+    cached_catalog_file = os.path.join(CONFIG.cache_dir, "catalog.xml")
+
+    # We can use cached copy if (a) we do not search and (b) it exists and (c) it is fresh
+    if (search is None) and use_cache:
+        if os.path.exists(cached_catalog_file):
+            cache_age = time.time() - os.stat(cached_catalog_file).st_mtime
+            if cache_age <= MAX_CACHE_AGE:
+                print("Reusing cached catalog ({0})".format(cached_catalog_file))
+                return return_from_catalog(cached_catalog_file)
+            else:
+                print("Cached catalog {0} is old ({1} days), generating new copy".format(
+                    cached_catalog_file, cache_age//DAY_SECONDS))
+    
+    temp_catalog_file = NamedTemporaryFile(suffix=".xml", delete=False)
+    temp_catalog_file.close()
+    temp_catalog_file = temp_catalog_file.name
 
     try:
-        subprocess.check_call(
-            [CONFIG.calibredb, "catalog", catalog_file] + options)
-        tree = objectify.parse(open(catalog_file))
-        root = tree.getroot()
-        return root.iterchildren(reversed=True)
-    except OSError as err:
-        if err.errno == 2:
-            raise Exception("""calibredb (configured as %s) not found.
-Install Calibre, or edit %s to set proper path to it.""" % (
-                    CONFIG.calibredb, CONFIG_LOCATION))
-        else:
-            raise
+        # Generate catalog to temporary file
+        generate_catalog(temp_catalog_file, options)
+
+        # If it went OK, and we do not search, preserve catalog for future
+        # (whether we wanted to use cache, or not, even if not, in future we may want it)
+        if search is None:
+            copyfile(temp_catalog_file, cached_catalog_file)
+
+        return return_from_catalog(temp_catalog_file)
     finally:
-        if not persist_catalog:
-            os.remove(catalog_file)
+        os.remove(temp_catalog_file)
 
 ############################################################
 # Public interface - general functions
