@@ -93,7 +93,11 @@ def run():
     known_by_calibre = defaultdict(lambda: set())
 
     for file_name in find_calibre_file_names(use_cache=options.cache):
-        chunk = file_size(file_name) // CHUNK_SIZE
+        try:
+            chunk = file_size(file_name) // CHUNK_SIZE
+        except OSError as e:
+            print("File {0} does not exist or can't be read, skipping from analysis.\n    Error details: {1}".format(file_name, str(e)))
+            continue
         known_by_calibre[chunk].add(file_name)
         known_by_calibre[chunk+1].add(file_name)
 
