@@ -38,6 +38,7 @@ Just open some terminal and run
      calibre_convert_docs_to_rtf
 
 """
+from __future__ import print_function
 
 import os
 import os.path
@@ -84,8 +85,8 @@ def make_rtf_for(item):
     """
     rtf_file = NamedTemporaryFile(suffix=".rtf", delete=False)
     rtf_name = rtf_file.name
-    print "Creating RTF for book %s (%s) in %s" % (
-        item.id, item.title, rtf_name)
+    print("Creating RTF for book %s (%s) in %s" % (
+        item.id, item.title, rtf_name))
     try:
         rtf_file.close()
         doc2rtf_converter.convert(item.file, rtf_name)
